==> create-flayyer-app-1.8.3.tgz: package/lib/index.js <==
"use strict";
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const command_1 = require("@oclif/command");
const enquirer_1 = require("enquirer");
const dedent_1 = tslib_1.__importDefault(require("dedent"));
const file_1 = require("./utils/file");
const debug_1 = require("./utils/debug");
const debug = debug_1.namespaced("new");
const TEMPLATES_DIR = path_1.default.join(__dirname, "..", "templates");
const CHOICES = fs_1.default.readdirSync(TEMPLATES_DIR).filter((name) => {
    return fs_1.default.lstatSync(path_1.default.join(TEMPLATES_DIR, name)).isDirectory();
});
class CreateFlayyerApp extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(CreateFlayyerApp);
        const response = await enquirer_1.prompt([
            {
                type: "input",
                name: "name",
                initial: args.name,
                skip: Boolean(args.name),
                message: "Enter project name",
                validate: Boolean,
            },
            {
                type: "autocomplete",
                name: "template",
                message: "Select the best template setup for you",
                hint: "You can customize the template later",
                initial: flags.template,
                skip: Boolean(flags.template),
                choices: CHOICES,
            },
        ]);
        const template = typeof response.template === "string" ? response.template : CHOICES[response.template];
        const name = slugify(response.name);
        debug("will use: %o", { name, template });
        const CURR_DIR = process.cwd();
        const templatePath = path_1.default.join(TEMPLATES_DIR, template);
        const targetPath = path_1.default.join(CURR_DIR, name);
        debug("current directory is: %s", CURR_DIR);
        debug("templates source directory is: %s", TEMPLATES_DIR);
        debug("template source directory is: %s", templatePath);
        debug("target path is: %s", targetPath);
        if (fs_1.default.existsSync(targetPath)) {
            this.error(`Folder ${targetPath} exists. Delete or use another name.`);
        }
        fs_1.default.mkdirSync(targetPath);
        const SKIP_FILES = ["node_modules"];
        const replace = { name: name, "cli-version": "^1.8.0" }; // TODO: find a way of getting this value
        const rename = { ".npmignore": ".gitignore" }; // For some (bold) reason, npm renames .gitignores to .npmignores
        debug("replacement values: %o", replace);
        debug("rename values: %o", rename);
        debug("skip files: %o", SKIP_FILES);
        debug("will copy and replace: %o", { from: templatePath, to: targetPath });
        file_1.recursiveCopy(templatePath, targetPath, SKIP_FILES, replace, rename);
        this.log(dedent_1.default `
      💫 Great!

      Project '${name}' with template '${template}' was successfully scaffolded in: ${targetPath}

      Now go to the generated directory and install the initial dependencies:

        cd ${name}
        npm install

      When you are ready to deploy execute:

        npm run build && npm run deploy

      Remember to setup your 'FLAYYER_KEY' environment variable.
      Forgot your key? Go to https://flayyer.com/
    `);
        debug("exiting oclif");
        this.exit();
    }
}
CreateFlayyerApp.description = "create a new flayyer project";
CreateFlayyerApp.flags = {
    // add --version flag to show CLI version
    version: command_1.flags.version({ char: "v" }),
    help: command_1.flags.help({ char: "h" }),
    template: command_1.flags.string({ char: "t", description: "starting template", options: CHOICES }),
};
CreateFlayyerApp.args = [{ name: "name", description: "output directory for templates" }];
// https://gist.github.com/codeguy/6684588#gistcomment-2690429
function slugify(str) {
    str = str.replace(/^\s+|\s+$/g, ""); // trim
    str = str.toLowerCase();
    // remove accents, swap ñ for n, etc
    const from = "åàáãäâèéëêìíïîòóöôùúüûñç·/_,:;";
    const to = "aaaaaaeeeeiiiioooouuuunc------";
    for (let i = 0, l = from.length; i < l; i++) {
        str = str.replace(new RegExp(from.charAt(i), "g"), to.charAt(i));
    }
    str = str
        .replace(/[^a-z0-9 -]/g, "") // remove invalid chars
        .replace(/\s+/g, "-") // collapse whitespace and replace by -
        .replace(/-+/g, "-") // collapse dashes
        .replace(/^-+/, "") // trim - from start of text
        .replace(/-+$/, ""); // trim - from end of text
    return str;
}
module.exports = CreateFlayyerApp;

==> create-flayyer-app-1.10.6.tgz: package/lib/index.js <==
"use strict";
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const command_1 = require("@oclif/command");
const dedent_1 = tslib_1.__importDefault(require("dedent"));
const enquirer_1 = require("enquirer");
const debug_1 = require("./utils/debug");
const file_1 = require("./utils/file");
const slugify_1 = require("./utils/slugify");
const debug = debug_1.namespaced("new");
const TEMPLATES_DIR = path_1.default.join(__dirname, "..", "templates");
const CHOICES = fs_1.default.readdirSync(TEMPLATES_DIR).filter((name) => {
    return fs_1.default.lstatSync(path_1.default.join(TEMPLATES_DIR, name)).isDirectory();
});
class CreateFlayyerApp extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(CreateFlayyerApp);
        const response = await enquirer_1.prompt([
            {
                type: "input",
                name: "name",
                initial: args.name,
                skip: Boolean(args.name),
                message: "Enter project name",
                validate: Boolean,
            },
            {
                type: "autocomplete",
                name: "template",
                message: "Select the best template setup for you",
                hint: "You can customize the template later",
                initial: flags.template,
                skip: Boolean(flags.template),
                choices: CHOICES,
            },
        ]);
        const template = typeof response.template === "string" ? response.template : CHOICES[response.template];
        const name = slugify_1.slugify(response.name);
        if (template) {
            debug("will use: %o", { name, template });
        }
        else {
            this.error("Missing or invalid template");
        }
        const CURR_DIR = process.cwd();
        const templatePath = path_1.default.join(TEMPLATES_DIR, template);
        const targetPath = path_1.default.join(CURR_DIR, name);
        debug("current directory is: %s", CURR_DIR);
        debug("templates source directory is: %s", TEMPLATES_DIR);
        debug("template source directory is: %s", templatePath);
        debug("target path is: %s", targetPath);
        if (fs_1.default.existsSync(targetPath)) {
            this.error(`Folder ${targetPath} exists. Delete or use another name.`);
        }
        fs_1.default.mkdirSync(targetPath);
        const SKIP_FILES = ["node_modules"];
        const replace = { name: name, "cli-version": "^1.9.1" }; // TODO: find a way of getting this value
        const rename = { ".npmignore": ".gitignore" }; // For some (bold) reason, npm renames .gitignores to .npmignores
        debug("replacement values: %o", replace);
        debug("rename values: %o", rename);
        debug("skip files: %o", SKIP_FILES);
        debug("will copy and replace: %o", { from: templatePath, to: targetPath });
        file_1.recursiveCopy(templatePath, targetPath, SKIP_FILES, replace, rename);
        this.log(dedent_1.default `
      💫 Great!

      Project '${name}' with template '${template}' was successfully scaffolded in: ${targetPath}

      Now go to the generated directory and install the initial dependencies:

        cd ${name}
        npm install

      When you are ready to deploy execute:

        npm run build && npm run deploy

      Remember to setup your 'FLAYYER_KEY' environment variable.
      Forgot your key? Go to https://flayyer.com/
    `);
        debug("exiting oclif");
        this.exit();
    }
}
CreateFlayyerApp.description = "create a new flayyer project";
CreateFlayyerApp.flags = {
    // add --version flag to show CLI version
    version: command_1.flags.version({ char: "v" }),
    help: command_1.flags.help({ char: "h" }),
    template: command_1.flags.string({ char: "t", description: "starting template", options: CHOICES }),
};
CreateFlayyerApp.args = [{ name: "name", description: "output directory for templates" }];
module.exports = CreateFlayyerApp;
